# remirepo/fedora spec file for php-netresearch-jsonmapper
#
# Copyright (c) 2017-2018 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#
%global gh_commit    3868fe1128ce1169228acdb623359dca74db5ef3
%global gh_short     %(c=%{gh_commit}; echo ${c:0:7})
%global gh_owner     cweiske
%global gh_project   jsonmapper

%global pk_vendor    netresearch
%global pk_project   jsonmapper

%global php_home     %{_datadir}/php
%global with_tests   0%{!?_without_tests:1}

Name:           php-%{pk_vendor}-%{pk_project}
Version:        1.4.0
Release:        1%{?dist}
Summary:        Map nested JSON structures onto PHP classes

License:        OSL 3.0
URL:            https://github.com/%{gh_owner}/%{gh_project}
Source0:        %{name}-%{version}-%{gh_short}.tgz
# Git snapshot with tests
Source1:        makesrc.sh

BuildArch:      noarch
%if %{with_tests}
# For tests
BuildRequires:  php(language) >= 5.6
BuildRequires:  php-pcre
BuildRequires:  php-spl
# From composer.json, "require-dev": {
#        "phpunit/phpunit": "~4.8.35 || ~5.7 || ~6.4",
#        "squizlabs/php_codesniffer": "~1.5"
%if 0%{?fedora} >= 26 || 0%{?rhel} >= 8
%global phpunit %{_bindir}/phpunit6
BuildRequires: phpunit6 >= 6.4
%else
%global phpunit %{_bindir}/phpunit
BuildRequires: php-phpunit-PHPUnit >= 4.8.35
%endif
# Required by autoloader
BuildRequires:  php-fedora-autoloader-devel
%endif

# From composer.json, "require": {
#      "php": ">=5.6"
Requires:       php(language) >= 5.6
# From phpcompatinfo report for version 1.3.0
Requires:       php-pcre
Requires:       php-spl
# Required by autoloader
Requires:       php-composer(fedora/autoloader)

Provides:       php-composer(%{pk_vendor}/%{pk_project}) = %{version}


%description
Takes data retrieved from a JSON web service and converts them into nested
object and arrays - using your own model classes.

Starting from a base object, it maps JSON data on class properties, converting
them into the correct simple types or objects.

It's a bit like the native SOAP parameter mapping PHP's SoapClient gives you,
but for JSON. It does not rely on any schema, only your PHP class definitions.

Type detection works by parsing @var docblock annotations of class properties,
as well as type hints in setter methods.

You do not have to modify your model classes by adding JSON specific code;
it works automatically by parsing already-existing docblocks.

Autoloader: %{php_home}/%{pk_vendor}/%{pk_project}/autoload.php


%prep
%setup -q -n %{gh_project}-%{gh_commit}


%build
phpab --template fedora --output src/autoload.php src


%install
: Library
mkdir -p   %{buildroot}%{php_home}/%{pk_vendor}
cp -pr src %{buildroot}%{php_home}/%{pk_vendor}/%{pk_project}


%check
%if %{with_tests}
mkdir vendor

: Run upstream test suite
ret=0
for cmd in "php %{phpunit}" php70 php71 php72 php73; do
  if which $cmd; then
    set $cmd
    $1 ${2:-%{_bindir}/phpunit6} \
      --bootstrap %{buildroot}%{php_home}/%{pk_vendor}/%{pk_project}/autoload.php \
      --no-coverage \
      --verbose . || ret=1
  fi
done
exit $ret
%else
: Test suite disabled
%endif


%files
%{!?_licensedir:%global license %%doc}
%license LICENSE
%doc composer.json
%doc ChangeLog README.rst
%dir %{php_home}/%{pk_vendor}
     %{php_home}/%{pk_vendor}/%{pk_project}


%changelog
* Mon Jan 22 2018 Remi Collet <remi@remirepo.net> - 1.4.0-1
- Update to 1.4.0
- use phpunit6 on F26+
- sources from git snapshot

* Sat Oct 21 2017 Remi Collet <remi@remirepo.net> - 1.3.0-1
- initial package, version 1.3.0
